@@ -143,10 +143,6 @@ class Server():
                 # For now, always use same port.
                 port = 1750
 
-            print("Observe that file transfer will only " \
-                    "work on your local network, \n" \
-                    "since the server is starting with internal host.")
-
             if self.use_log:
                 self._update_log('info', 'Server starting locally.')
 
@@ -339,17 +335,16 @@ class Server():
 
                     byte_data = list()
                     while True:
-                        partial = connection.recv(2**16)
-                        if len(partial) <= 0:
+                        partial = connection.recv(2**12)
+                        if not partial:
                             break
 
                         # Appending the partial data to list is a lot
                         # faster than concatenate byte strings.
                         byte_data.append(partial)
-
+                    
                     if byte_data:
                         data = pickle.loads(b''.join(byte_data))
-
                         for item in data:
                             path = self.def_path / item.path
                             if item.type_ == "folder":
@@ -360,7 +355,7 @@ class Server():
                                             path))
 
                             elif item.type_ == "file":
-                                with open(path, 'w') as f:
+                                with open(path, 'wb') as f:
                                     f.write(item.content)
 
                                 if self.use_log:
